
BRANCHES_PREFIXES = {
    'bugfix': 'Bugfix',
    'fix': 'Bugfix', 
    'documentation': 'Documentation', 
    'doc': 'Documentation',
    'feature': 'Feature', 
    'structure': 'Structure',
    'devops': 'CI/CD',
    'ci': 'CI/CD',
    'cd': 'CI/CD',
    'enhancement': 'Enhancement',
    'improve': 'Enhancement',
    'improvement': 'Enhancement'
}
